@@ -1,6 +1,6 @@
 // Copyright Contributors to the Open Shading Language project.
 // SPDX-License-Identifier: BSD-3-Clause
-// https://github.com/imageworks/OpenShadingLanguage
+// https://github.com/AcademySoftwareFoundation/OpenShadingLanguage
 
 #pragma once
 
@@ -16,7 +16,6 @@
                              (100*OPENEXR_VERSION_MINOR) + \
                              OPENEXR_VERSION_PATCH)
 #if OSL_OPENEXR_VERSION >= 20599 /* 2.5.99: pre-3.0 */
-#   include <Imath/ImathLimits.h>
 #   include <Imath/ImathVec.h>
 #   include <Imath/ImathMatrix.h>
 #   include <Imath/ImathColor.h>
